@@ -11,8 +11,7 @@
 #include "kbreakout_debug.h"
 #include "settings.h"
 // KDEGames
-#include <kdegames_version.h>
-#include <KgThemeProvider>
+#include <KGameThemeProvider>
 // KF
 #include <KLocalizedContext>
 // Qt
@@ -25,7 +24,7 @@
 
 CanvasWidget::CanvasWidget(QWidget *parent) :
     QQuickWidget(parent),
-    m_provider(new KgThemeProvider)
+    m_provider(new KGameThemeProvider)
 {
     QQmlEngine *engine = this->engine();
 
@@ -34,11 +33,7 @@ CanvasWidget::CanvasWidget(QWidget *parent) :
 
     setResizeMode(SizeRootObjectToView);
 
-#if KDEGAMES_VERSION >= QT_VERSION_CHECK(7, 4, 0)
     m_provider->discoverThemes(QStringLiteral("themes"));
-#else
-    m_provider->discoverThemes("appdata", QStringLiteral("themes"));
-#endif
     m_provider->setDeclarativeEngine(QStringLiteral("themeProvider"), engine);
     QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("qml/main.qml"));
 
